@@ -1,6 +1,4 @@
 import asyncio
-
-from deepfos_ipc_protocol.const import MESSAGE_PROTOCOL, HEADER_PROTOCOL, DETAILLIST_PROTOCOL
 from deepfos_ipc_protocol.utils import (
     judge_data_format,
     to_msg_protocol,
@@ -8,6 +6,12 @@ from deepfos_ipc_protocol.utils import (
     to_detaillist_protocol,
     logging
 )
+from configs import const
+
+
+HEADER_PROTOCOL = const.HEADER_PROTOCOL
+MESSAGE_PROTOCOL = const.MESSAGE_PROTOCOL
+DETAILLIST_PROTOCOL = const.DETAILLIST_PROTOCOL
 
 
 logger = logging.getLogger(__name__)
@@ -41,17 +45,21 @@ class WorkerClient:
     transport = None
     path = None
 
-    def __new__(cls, path=None):
+    def __new__(cls, path=None, config=None):
         if not hasattr(cls, '_instance'):
             cls._instance = super().__new__(cls)
         return cls._instance
 
-    def __init__(self, path: str = None):
+    def __init__(self, path: str = None, config=None):
         if not self.path:
             self.path = path
         if self.path is None:
             raise Exception("path is not None")
-
+        if not config:
+            const.read_config("./configs/default.json")
+        else:
+            const.read_config(config)
+            
     def _processing_data(self, mtype: str, data):
         '''将传入的数据转为服务端可读取的数据'''
         if mtype in MESSAGE_PROTOCOL:
@@ -91,3 +99,43 @@ class WorkerClient:
         await cls.future
         cls._instance.transport.close()
 
+# async def async_main():
+#     m = WorkerClient("../unix_sock.sock", config="/Users/chenxingyu/Desktop/fenghe/deepfos-ipc-protocol/aaa.json")
+#     await m.create_conn() # 建立一个连接
+#     await m.send_msg("O", "你好")
+
+#     await WorkerClient.send_msg(
+#         "U", [
+#             {
+#                 "key": "key",
+#                 "name": "你好",
+#                 "status": "status",
+#                 "endTime": "endTime",
+#                 "arg": "xxxx"
+#             }
+#         ]
+#     )
+#     await WorkerClient.send_msg(
+#         "H", {"header": "你好"}
+#     )
+#     await WorkerClient.send_msg(
+#         "I", [
+#             {
+#                 "key": "key",
+#                 "name": "name",
+#             }
+#         ]
+#     )
+#     await WorkerClient.send_msg(
+#         "E", "xxxss"
+#     )
+#     await WorkerClient.send_msg(
+#         "e", {"subtask_err": "err", "arg": "arg"}
+#     )
+#     await WorkerClient.send_msg(
+#         "o", {"subtask_out": "out", "arg": "arg"}
+#     )
+#     await m.close()
+#     await m.send_msg("O", "hello3")
+
+# asyncio.run(async_main())
