@@ -1,5 +1,4 @@
 import asyncio
-
 from inspect import isfunction
 from deepfos_ipc_protocol.utils import (
     resolve_header_protocol,
@@ -7,11 +6,12 @@ from deepfos_ipc_protocol.utils import (
     resolve_detaillist_protocol,
     logging
 )
-from deepfos_ipc_protocol.const import (
-    HEADER_PROTOCOL,
-    MESSAGE_PROTOCOL,
-    DETAILLIST_PROTOCOL
-)
+from configs import const
+
+
+HEADER_PROTOCOL = const.HEADER_PROTOCOL
+MESSAGE_PROTOCOL = const.MESSAGE_PROTOCOL
+DETAILLIST_PROTOCOL = const.DETAILLIST_PROTOCOL
 
 
 logger = logging.getLogger(__name__)
@@ -66,12 +66,16 @@ class MasterServer:
     """
     启动MasterServer服务.
     """
-    def __init__(self, path: str, ins=None, **kwargs) -> None:
+    def __init__(self, path: str, ins=None, config=None, **kwargs) -> None:
         self.path = path
         self.ins = ins
         self.kwargs = kwargs
         self.func = self.get_func()
         self.waiter = None
+        if not config:
+            const.read_config("./configs/default.json")
+        else:
+            const.read_config(config)
 
     def get_func(self):
         if isinstance(self.ins, type) and hasattr(self.ins, self.kwargs.get("func")):
@@ -99,3 +103,9 @@ class MasterServer:
         logger.info('Master Server stop.')
         self.waiter.set_result(None)
         logger.info('Master Server stop complete.')
+
+# async def run():
+#     m = MasterServer("../unix_sock.sock", config="/Users/chenxingyu/Desktop/fenghe/deepfos-ipc-protocol/aaa.json")
+#     await m.task()
+
+# asyncio.run(run())
